@@ -382,7 +382,7 @@ def update_ssh_config_entry(engine_name: str, instance_id: str, ssh_user: str):
 Host {engine_name} {SSH_MANAGED_COMMENT}
     HostName {instance_id}
     User {ssh_user}
-    ProxyCommand sh -c "aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'"
+    ProxyCommand sh -c "aws ssm start-session --target %h --document-name AWS-StartSSHSession --idle-timeout 600 --parameters 'portNumber=%p'"
 """
 
     # Check if entry already exists
@@ -945,7 +945,7 @@ def config_ssh(
                     f"Host {engine['name']} {SSH_MANAGED_COMMENT}",
                     f"    HostName {engine['instance_id']}",
                     f"    User {ssh_user}",
-                    f"    ProxyCommand sh -c \"aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\"",
+                    f"    ProxyCommand sh -c \"aws ssm start-session --target %h --document-name AWS-StartSSHSession --idle-timeout 600 --parameters 'portNumber=%p'\"",
                 ]
             )
 
@@ -1253,7 +1253,7 @@ def create_ami(
     console.print(f"AMI Name: [cyan]{ami_name}[/cyan]")
     console.print(f"Description: {ami_description}")
     console.print(
-        "\n[yellow]⚠️  Important: This will reboot the engine to ensure a clean snapshot.[/yellow]"
+        "\n[yellow]⚠️  Important: This will detach all studios and reboot the engine to ensure a clean snapshot.[/yellow]"
     )
 
     if not Confirm.ask("\nContinue with AMI creation?"):
@@ -1322,15 +1322,10 @@ def create_ami(
         attached_studios = attached_resp.json().get("studios", []) if attached_resp.status_code == 200 else []
 
         if attached_studios:
-            console.print(f"[yellow]⚠  {len(attached_studios)} studio(s) attached to this engine.[/yellow]")
+            console.print(f"Detaching {len(attached_studios)} studio(s) from this engine…")
             for s in attached_studios:
                 console.print(f"  • {s['user']} ({s['studio_id']})")
 
-            if not Confirm.ask("Detach all studios before AMI creation?"):
-                console.print("AMI creation cancelled.")
-                return
-
-            console.print("Detaching studios…")
             for s in attached_studios:
                 resp = make_api_request("POST", f"/studios/{s['studio_id']}/detach")
                 if resp.status_code != 200:
@@ -1354,9 +1349,7 @@ def create_ami(
             TextColumn("[progress.description]{task.description}"),
             transient=True,
         ) as progress:
-            progress.add_task(
-                "Creating AMI (this will take several minutes)...", total=None
-            )
+            progress.add_task("Creating AMI (this will take several minutes)...", total=None)
 
             create_params = {
                 "InstanceId": engine["instance_id"],
